==> customize-easy-ui-component-3.5.9.tgz: package/esm/stories/Button.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { Button } from "../Button";
import { storiesOf } from "@storybook/react";
import theme from "../Theme";
import { DarkMode, useTheme, LightMode } from "../Theme/Providers";
import { IconArrowLeft, IconArrowRight } from "../Icons";
export var ButtonStories = storiesOf("Button", module)
    .add("submit", function () {
    return (jsx("form", { onSubmit: function (e) {
            e.preventDefault();
            console.log("submit");
        } },
        jsx("input", { type: "text" }),
        jsx(Button, { type: "submit" }, "Submit")));
})
    .add("variants", function () {
    var sizes = ["xs", "sm", "md", "lg", "xl"];
    var appearance = ["default", "ghost", "outline"];
    var intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (jsx("div", null, appearance.map(function (appearance) { return (jsx("div", { key: appearance }, sizes.map(function (size) { return (jsx("div", { key: size, style: { padding: "0.5rem" } }, intents.map(function (intent) { return (jsx(Button, { key: size + appearance, size: size, css: { marginRight: "1rem", textTransform: "capitalize" }, variant: appearance, intent: intent, onPress: function () { return console.log("hello there"); } }, intent)); }))); }))); })));
})
    .add("disabled", function () {
    var variants = ["default", "ghost", "outline"];
    var intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (jsx("div", null, variants.map(function (variant) {
        return (jsx("div", { key: variant }, intents.map(function (intent) { return (jsx(Button, { key: intent, css: { margin: "1rem" }, intent: intent, disabled: true, variant: variant }, intent)); })));
    })));
})
    .add("with icons", function () { return (jsx("div", { css: {
        "& > *": {
            margin: theme.spaces.md
        }
    } },
    jsx(Button, { iconBefore: jsx(IconArrowLeft, null) }, "Icon before"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null) }, "Icon after"),
    jsx(Button, { iconBefore: jsx(IconArrowLeft, null), iconAfter: jsx(IconArrowRight, null) }, "Icon before and after"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary" }, "Icon after"),
    jsx(Button, { component: "a", href: "#", iconAfter: jsx(IconArrowRight, null), intent: "primary" }, "Icon after anchor"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "outline" }, "Icon after"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "ghost" }, "Icon after"),
    ["xs", "sm", "md", "lg", "xl"].map(function (size) {
        return (jsx(Button, { key: size, size: size, iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "outline" }, "Icon after"));
    }))); })
    .add("block", function () {
    return (jsx("div", { css: {
            margin: "1rem",
            "& > *": {
                maxWidth: "300px",
                marginTop: theme.spaces.md
            }
        } },
        jsx(Button, { block: true }, "Hello"),
        jsx(Button, { block: true, iconBefore: jsx(IconArrowRight, null) }, "with icon before"),
        jsx(Button, { block: true, iconAfter: jsx(IconArrowRight, null) }, "With icon after"),
        jsx(Button, { block: true, iconBefore: jsx(IconArrowRight, null), iconAfter: jsx(IconArrowRight, null) }, "Two icons"),
        jsx(Button, { component: "a", href: "@", block: true, iconAfter: jsx(IconArrowRight, null) }, "Anchor icon after")));
})
    .add("contrast checks", function () {
    return jsx(ContrastExample, null);
});
function ContrastExample() {
    var theme = useTheme();
    return (jsx(DarkMode, null,
        jsx(React.Fragment, null,
            jsx("div", { css: {
                    padding: "2rem",
                    background: theme.colors.intent.none.base,
                    "& > *": { margin: "1rem" }
                } },
                jsx(Button, null, "Hello world"),
                jsx(Button, { intent: "primary" }, "Primary"),
                jsx(Button, { intent: "success" }, "Success"),
                jsx(Button, { intent: "warning" }, "Warning"),
                jsx(Button, { intent: "danger" }, "Warning")),
            jsx(LightMode, null,
                jsx("div", { css: {
                        padding: "2rem",
                        background: theme.colors.background.tint2,
                        "& > *": { margin: "1rem" }
                    } },
                    jsx(Button, null, "Hello world"),
                    jsx(Button, { intent: "primary" }, "Primary"),
                    jsx(Button, { intent: "success" }, "Success"),
                    jsx(Button, { intent: "warning" }, "Warning"),
                    jsx(Button, { intent: "danger" }, "Warning"))),
            jsx("div", { css: {
                    padding: "2rem",
                    background: theme.colors.intent.primary.dark,
                    "& > *": { margin: "1rem" }
                } },
                jsx(Button, null, "Hello world"),
                jsx(Button, { intent: "primary" }, "Primary"),
                jsx(Button, { intent: "success" }, "Success"),
                jsx(Button, { intent: "warning" }, "Warning"),
                jsx(Button, { intent: "danger" }, "Warning")))));
}

==> customize-easy-ui-component-4.2.0.tgz: package/esm/stories/Button.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { Button } from "../Button";
import { storiesOf } from "@storybook/react";
import theme from "../Theme";
import { DarkMode, useTheme, LightMode } from "../Theme/Providers";
import { IconArrowLeft, IconArrowRight } from "../Icons";
export const ButtonStories = storiesOf("Button", module)
    .add("submit", () => {
    return (jsx("form", { onSubmit: e => {
            e.preventDefault();
            console.log("submit");
        } },
        jsx("input", { type: "text" }),
        jsx(Button, { type: "submit" }, "Submit")));
})
    .add("variants", () => {
    const sizes = ["xs", "sm", "md", "lg", "xl"];
    const appearance = ["default", "ghost", "outline"];
    const intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (jsx("div", null, appearance.map(appearance => (jsx("div", { key: appearance }, sizes.map(size => (jsx("div", { key: size, style: { padding: "0.5rem" } }, intents.map(intent => (jsx(Button, { key: size + appearance, size: size, css: { marginRight: "1rem", textTransform: "capitalize" }, variant: appearance, intent: intent, onPress: () => console.log("hello there") }, intent)))))))))));
})
    .add("disabled", () => {
    const variants = ["default", "ghost", "outline"];
    const intents = [
        "none",
        "primary",
        "success",
        "danger",
        "warning"
    ];
    return (jsx("div", null, variants.map(variant => {
        return (jsx("div", { key: variant }, intents.map(intent => (jsx(Button, { key: intent, css: { margin: "1rem" }, intent: intent, disabled: true, variant: variant }, intent)))));
    })));
})
    .add("with icons", () => (jsx("div", { css: {
        "& > *": {
            margin: theme.spaces.md
        }
    } },
    jsx(Button, { iconBefore: jsx(IconArrowLeft, null) }, "Icon before"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null) }, "Icon after"),
    jsx(Button, { iconBefore: jsx(IconArrowLeft, null), iconAfter: jsx(IconArrowRight, null) }, "Icon before and after"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary" }, "Icon after"),
    jsx(Button, { component: "a", href: "#", iconAfter: jsx(IconArrowRight, null), intent: "primary" }, "Icon after anchor"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "outline" }, "Icon after"),
    jsx(Button, { iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "ghost" }, "Icon after"),
    ["xs", "sm", "md", "lg", "xl"].map(size => {
        return (jsx(Button, { key: size, size: size, iconAfter: jsx(IconArrowRight, null), intent: "primary", variant: "outline" }, "Icon after"));
    }))))
    .add("block", () => {
    return (jsx("div", { css: {
            margin: "1rem",
            "& > *": {
                maxWidth: "300px",
                marginTop: theme.spaces.md
            }
        } },
        jsx(Button, { block: true }, "Hello"),
        jsx(Button, { block: true, iconBefore: jsx(IconArrowRight, null) }, "with icon before"),
        jsx(Button, { block: true, iconAfter: jsx(IconArrowRight, null) }, "With icon after"),
        jsx(Button, { block: true, iconBefore: jsx(IconArrowRight, null), iconAfter: jsx(IconArrowRight, null) }, "Two icons"),
        jsx(Button, { component: "a", href: "@", block: true, iconAfter: jsx(IconArrowRight, null) }, "Anchor icon after")));
})
    .add("contrast checks", () => {
    return jsx(ContrastExample, null);
});
function ContrastExample() {
    const theme = useTheme();
    return (jsx(DarkMode, null,
        jsx(React.Fragment, null,
            jsx("div", { css: {
                    padding: "2rem",
                    background: theme.colors.intent.none.base,
                    "& > *": { margin: "1rem" }
                } },
                jsx(Button, null, "Hello world"),
                jsx(Button, { intent: "primary" }, "Primary"),
                jsx(Button, { intent: "success" }, "Success"),
                jsx(Button, { intent: "warning" }, "Warning"),
                jsx(Button, { intent: "danger" }, "Warning")),
            jsx(LightMode, null,
                jsx("div", { css: {
                        padding: "2rem",
                        background: theme.colors.background.tint2,
                        "& > *": { margin: "1rem" }
                    } },
                    jsx(Button, null, "Hello world"),
                    jsx(Button, { intent: "primary" }, "Primary"),
                    jsx(Button, { intent: "success" }, "Success"),
                    jsx(Button, { intent: "warning" }, "Warning"),
                    jsx(Button, { intent: "danger" }, "Warning"))),
            jsx("div", { css: {
                    padding: "2rem",
                    background: theme.colors.intent.primary.dark,
                    "& > *": { margin: "1rem" }
                } },
                jsx(Button, null, "Hello world"),
                jsx(Button, { intent: "primary" }, "Primary"),
                jsx(Button, { intent: "success" }, "Success"),
                jsx(Button, { intent: "warning" }, "Warning"),
                jsx(Button, { intent: "danger" }, "Warning")))));
}
